import { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom'
import { Service } from '../Utils/HTTP';
import { useSelector } from 'react-redux';
import { Button  } from '@mui/material'
import { Document, Page, pdfjs } from 'react-pdf/dist/esm/entry.webpack';
// import 'react-pdf/dist/esm/Page/AnnotationLayer.css';
import 'react-pdf/dist/esm/Page/AnnotationLayer.css';
import 'react-pdf/dist/esm/Page/TextLayer.css';

const Cargando = () => <div><h2>loading...</h2></div>

// Create Document Component
const MyDocument = (props) => {

  let { pdf } = props;
  const [numPages, setNumPages] = useState(null);
  const [pageNumber, setPageNumber] = useState(1);

  function onDocumentLoadSuccess({ numPages }) {
    console.log('numero de pagians',numPages)
    setNumPages(numPages);
  }

  function onLoadError(error){
    console.log('error: ', error)
  }

  return (
    <div>
      <div>
        <Button  onClick={() =>setPageNumber(pageNumber + 1)} >
          Siguiente
        </Button>
      </div>
      <Document renderMode="canvas" file={pdf.data} onLoadSuccess={onDocumentLoadSuccess} onLoadError={onLoadError}>
        <Page  pageNumber={pageNumber} loading={<Cargando/>} />
      </Document>
      <p>
        Page {pageNumber} of {numPages}
      </p>
    </div>
  )
};


export function Resultados() {

  let { id } = useParams();
  let auth = useSelector((state) => state.token)
  let [pdf, setPdf] = useState(null);

  useEffect(() => {

    let url = `/report/cleaverResult/${id}?output=pdf`
    let rest = new Service(url);

    pdfjs.GlobalWorkerOptions.workerSrc =  `https://cdnjs.cloudflare.com/ajax/libs/pdf.js/${pdfjs.version}/pdf.worker.js`;

    rest
      .getBlob(auth.token)
      .then(blob => setPdf(blob))
      .catch(error => console.log({ error }))

  }, [auth, id])

  return (
    <div className="content-section">
      <div className="main">
        <h1>Resultados {id}</h1>
        <hr />
        {
          pdf ?
            <MyDocument pdf={pdf} />
            : <div> <h5> loading...</h5></div>
        }
      </div>
    </div>
  )
}
